<a id="mypy-boto3-ssm-contacts"></a>

# mypy-boto3-ssm-contacts

[![PyPI - mypy-boto3-ssm-contacts](https://img.shields.io/pypi/v/mypy-boto3-ssm-contacts.svg?color=blue)](https://pypi.org/project/mypy-boto3-ssm-contacts)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-ssm-contacts.svg?color=blue)](https://pypi.org/project/mypy-boto3-ssm-contacts)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-ssm-contacts?color=blue)](https://pypistats.org/packages/mypy-boto3-ssm-contacts)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.SSMContacts 1.18.47](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/ssm-contacts.html#SSMContacts)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-ssm-contacts docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_contacts/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-ssm-contacts](#mypy-boto3-ssm-contacts)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `SSMContacts` service.

```bash
python -m pip install boto3-stubs[ssm-contacts]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[ssm-contacts]` in your environment:
  `python -m pip install 'boto3-stubs[ssm-contacts]'`

Both type checking and auto-complete should work for `SSMContacts` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[ssm-contacts]` in your environment:
  `python -m pip install 'boto3-stubs[ssm-contacts]'`

Both type checking and auto-complete should work for `SSMContacts` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[ssm-contacts]` in your environment:
  `python -m pip install 'boto3-stubs[ssm-contacts]'`
- Run `mypy` as usual

Type checking should work for `SSMContacts` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[ssm-contacts]` in your environment:
  `python -m pip install 'boto3-stubs[ssm-contacts]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `SSMContacts` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`SSMContactsClient` provides annotations for `boto3.client("ssm-contacts")`.

```python
import boto3

from mypy_boto3_ssm_contacts import SSMContactsClient

client: SSMContactsClient = boto3.client("ssm-contacts")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SSMContactsClient = session.client("ssm-contacts")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_ssm_contacts.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_ssm_contacts import SSMContactsClient
from mypy_boto3_ssm_contacts.paginator import (
    ListContactChannelsPaginator,
    ListContactsPaginator,
    ListEngagementsPaginator,
    ListPageReceiptsPaginator,
    ListPagesByContactPaginator,
    ListPagesByEngagementPaginator,
)

client: SSMContactsClient = boto3.client("ssm-contacts")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_contact_channels_paginator: ListContactChannelsPaginator = client.get_paginator("list_contact_channels")
list_contacts_paginator: ListContactsPaginator = client.get_paginator("list_contacts")
list_engagements_paginator: ListEngagementsPaginator = client.get_paginator("list_engagements")
list_page_receipts_paginator: ListPageReceiptsPaginator = client.get_paginator("list_page_receipts")
list_pages_by_contact_paginator: ListPagesByContactPaginator = client.get_paginator("list_pages_by_contact")
list_pages_by_engagement_paginator: ListPagesByEngagementPaginator = client.get_paginator("list_pages_by_engagement")
```

<a id="literals"></a>

### Literals

`mypy_boto3_ssm_contacts.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_ssm_contacts.literals import (
    AcceptCodeValidationType,
    AcceptTypeType,
    ActivationStatusType,
    ChannelTypeType,
    ContactTypeType,
    ListContactChannelsPaginatorName,
    ListContactsPaginatorName,
    ListEngagementsPaginatorName,
    ListPageReceiptsPaginatorName,
    ListPagesByContactPaginatorName,
    ListPagesByEngagementPaginatorName,
    ReceiptTypeType,
    ServiceName,
)

def check_value(value: AcceptCodeValidationType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_ssm_contacts.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_ssm_contacts.type_defs import (
    AcceptPageRequestRequestTypeDef,
    ActivateContactChannelRequestRequestTypeDef,
    ChannelTargetInfoTypeDef,
    ContactChannelAddressTypeDef,
    ContactChannelTypeDef,
    ContactTargetInfoTypeDef,
    ContactTypeDef,
    CreateContactChannelRequestRequestTypeDef,
    CreateContactChannelResultTypeDef,
    CreateContactRequestRequestTypeDef,
    CreateContactResultTypeDef,
    DeactivateContactChannelRequestRequestTypeDef,
    DeleteContactChannelRequestRequestTypeDef,
    DeleteContactRequestRequestTypeDef,
    DescribeEngagementRequestRequestTypeDef,
    DescribeEngagementResultTypeDef,
    DescribePageRequestRequestTypeDef,
    DescribePageResultTypeDef,
    EngagementTypeDef,
    GetContactChannelRequestRequestTypeDef,
    GetContactChannelResultTypeDef,
    GetContactPolicyRequestRequestTypeDef,
    GetContactPolicyResultTypeDef,
    GetContactRequestRequestTypeDef,
    GetContactResultTypeDef,
    ListContactChannelsRequestRequestTypeDef,
    ListContactChannelsResultTypeDef,
    ListContactsRequestRequestTypeDef,
    ListContactsResultTypeDef,
    ListEngagementsRequestRequestTypeDef,
    ListEngagementsResultTypeDef,
    ListPageReceiptsRequestRequestTypeDef,
    ListPageReceiptsResultTypeDef,
    ListPagesByContactRequestRequestTypeDef,
    ListPagesByContactResultTypeDef,
    ListPagesByEngagementRequestRequestTypeDef,
    ListPagesByEngagementResultTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResultTypeDef,
    PageTypeDef,
    PaginatorConfigTypeDef,
    PlanTypeDef,
    PutContactPolicyRequestRequestTypeDef,
    ReceiptTypeDef,
    ResponseMetadataTypeDef,
    SendActivationCodeRequestRequestTypeDef,
    StageTypeDef,
    StartEngagementRequestRequestTypeDef,
    StartEngagementResultTypeDef,
    StopEngagementRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TargetTypeDef,
    TimeRangeTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateContactChannelRequestRequestTypeDef,
    UpdateContactRequestRequestTypeDef,
)

def get_structure() -> AcceptPageRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-ssm-contacts` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-ssm-contacts docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_contacts/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
